@@ -1,9 +1,7 @@
 package Syccess;
-BEGIN {
-  $Syccess::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Easy Validation Handler
-$Syccess::VERSION = '0.103';
+$Syccess::VERSION = '0.104';
 use Moo;
 use Module::Runtime qw( use_module );
 use Tie::IxHash;
@@ -166,7 +164,7 @@ Syccess - Easy Validation Handler
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
@@ -378,16 +376,16 @@ hope I will find later the time to make this possible.
 
 IRC
 
-  Join #sycontent on irc.perl.org. Highlight Getty for fast reaction :).
+  Join irc.perl.org and msg Getty
 
 Repository
 
-  http://github.com/SyContent/Syccess
+  http://github.com/Getty/p5-syccess
   Pull request and additional contributors are welcome
 
 Issue Tracker
 
-  http://github.com/SyContent/Syccess/issues
+  http://github.com/Getty/p5-syccess/issues
 
 =head1 AUTHOR
 
@@ -395,7 +393,7 @@ Torsten Raudssus <torsten@raudss.us>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Torsten Raudssus.
+This software is copyright (c) 2017 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
