@@ -1,9 +1,7 @@
 package Syccess::Error;
-BEGIN {
-  $Syccess::Error::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Syccess error message
-$Syccess::Error::VERSION = '0.103';
+$Syccess::Error::VERSION = '0.104';
 use Moo;
 
 with qw(
@@ -58,7 +56,7 @@ Syccess::Error - Syccess error message
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 DESCRIPTION
 
@@ -100,18 +98,16 @@ with the given procedure.
 
 IRC
 
-  Join #sycontent on irc.perl.org. Highlight Getty for fast reaction :).
+  Join irc.perl.org and msg Getty
 
 Repository
 
-  http://github.com/SyContent/Syccess
+  http://github.com/Getty/p5-syccess
   Pull request and additional contributors are welcome
 
 Issue Tracker
 
-  http://github.com/SyContent/Syccess/issues
-
-=cut
+  http://github.com/Getty/p5-syccess/issues
 
 =head1 AUTHOR
 
@@ -119,7 +115,7 @@ Torsten Raudssus <torsten@raudss.us>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Torsten Raudssus.
+This software is copyright (c) 2017 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
