@@ -1,9 +1,7 @@
 package Syccess::Field;
-BEGIN {
-  $Syccess::Field::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Syccess field
-$Syccess::Field::VERSION = '0.103';
+$Syccess::Field::VERSION = '0.104';
 use Moo;
 use Module::Runtime qw( use_module );
 use Module::Load::Conditional qw( can_load );
@@ -40,7 +38,9 @@ sub _build_label {
       return $arg if $key eq 'label';
     }
   }
-  return ucfirst($self->name);
+  my $name = $self->name;
+  $name =~ s/_([a-z])/ \U$1/g;
+  return ucfirst($name);
 }
 
 has validators_args => (
@@ -102,7 +102,7 @@ sub load_class_by_key {
     }
   } else {
     my $module = $key;
-    $module =~ s/_([a-z])/\U$1/;
+    $module =~ s/_([a-z])/\U$1/g;
     $module = ucfirst($module);
     my @namespaces = @{$self->syccess->validator_namespaces};
     for my $namespace (@namespaces) {
@@ -139,7 +139,7 @@ Syccess::Field - Syccess field
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 DESCRIPTION
 
@@ -177,18 +177,16 @@ and give them back in return.
 
 IRC
 
-  Join #sycontent on irc.perl.org. Highlight Getty for fast reaction :).
+  Join irc.perl.org and msg Getty
 
 Repository
 
-  http://github.com/SyContent/Syccess
+  http://github.com/Getty/p5-syccess
   Pull request and additional contributors are welcome
 
 Issue Tracker
 
-  http://github.com/SyContent/Syccess/issues
-
-=cut
+  http://github.com/Getty/p5-syccess/issues
 
 =head1 AUTHOR
 
@@ -196,7 +194,7 @@ Torsten Raudssus <torsten@raudss.us>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Torsten Raudssus.
+This software is copyright (c) 2017 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
