@@ -1,9 +1,7 @@
 package Syccess::Validator::IsNumber;
-BEGIN {
-  $Syccess::Validator::IsNumber::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: A validator to check if value is a number
-$Syccess::Validator::IsNumber::VERSION = '0.103';
+$Syccess::Validator::IsNumber::VERSION = '0.104';
 use Moo;
 use Scalar::Util qw( looks_like_number );
 
@@ -37,7 +35,7 @@ Syccess::Validator::IsNumber - A validator to check if value is a number
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
@@ -67,18 +65,16 @@ generation. See L<Syccess::Error/validator_message>.
 
 IRC
 
-  Join #sycontent on irc.perl.org. Highlight Getty for fast reaction :).
+  Join irc.perl.org and msg Getty
 
 Repository
 
-  http://github.com/SyContent/Syccess
+  http://github.com/Getty/p5-syccess
   Pull request and additional contributors are welcome
 
 Issue Tracker
 
-  http://github.com/SyContent/Syccess/issues
-
-=cut
+  http://github.com/Getty/p5-syccess/issues
 
 =head1 AUTHOR
 
@@ -86,7 +82,7 @@ Torsten Raudssus <torsten@raudss.us>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Torsten Raudssus.
+This software is copyright (c) 2017 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
