@@ -1,9 +1,7 @@
 package Syccess::Validator::Length;
-BEGIN {
-  $Syccess::Validator::Length::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: A validator to check the length of the value in chars
-$Syccess::Validator::Length::VERSION = '0.103';
+$Syccess::Validator::Length::VERSION = '0.104';
 use Moo;
 use Carp qw( croak );
 
@@ -96,7 +94,7 @@ Syccess::Validator::Length - A validator to check the length of the value in cha
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
@@ -143,18 +141,16 @@ generation. See L<Syccess::Error/validator_message>.
 
 IRC
 
-  Join #sycontent on irc.perl.org. Highlight Getty for fast reaction :).
+  Join irc.perl.org and msg Getty
 
 Repository
 
-  http://github.com/SyContent/Syccess
+  http://github.com/Getty/p5-syccess
   Pull request and additional contributors are welcome
 
 Issue Tracker
 
-  http://github.com/SyContent/Syccess/issues
-
-=cut
+  http://github.com/Getty/p5-syccess/issues
 
 =head1 AUTHOR
 
@@ -162,7 +158,7 @@ Torsten Raudssus <torsten@raudss.us>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Torsten Raudssus.
+This software is copyright (c) 2017 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
