@@ -1,9 +1,7 @@
 package Syccess::ValidatorSimple;
-BEGIN {
-  $Syccess::ValidatorSimple::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Syccess validator
-$Syccess::ValidatorSimple::VERSION = '0.103';
+$Syccess::ValidatorSimple::VERSION = '0.104';
 use Moo::Role;
 
 with qw(
@@ -47,7 +45,7 @@ Syccess::ValidatorSimple - Syccess validator
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
@@ -91,18 +89,16 @@ validator object, but no value itself (if you override B<missing_ok>).
 
 IRC
 
-  Join #sycontent on irc.perl.org. Highlight Getty for fast reaction :).
+  Join irc.perl.org and msg Getty
 
 Repository
 
-  http://github.com/SyContent/Syccess
+  http://github.com/Getty/p5-syccess
   Pull request and additional contributors are welcome
 
 Issue Tracker
 
-  http://github.com/SyContent/Syccess/issues
-
-=cut
+  http://github.com/Getty/p5-syccess/issues
 
 =head1 AUTHOR
 
@@ -110,7 +106,7 @@ Torsten Raudssus <torsten@raudss.us>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Torsten Raudssus.
+This software is copyright (c) 2017 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
